Crate thread_future

Crate thread_future 

Structs

SimpleCancellationToken
An ultra-simple cancellation token that can be cloned and shared across threads.
ThreadFuture
Create a future that wraps a thread. The thread is lazily created. The thread is not (and cannot be) terminated when this structure is dropped. The thread must behave nicely and check the cancellation token given to see if it should terminate.

Enums

ThreadFutureState

Traits

CancellationToken