pub enum ThreadFutureState<T, F> {
NotStarted(F),
Running(JoinHandle<T>),
Completed,
Polling,
}Variants
NotStarted(F)
The thread has not been started yet, the work function is waiting
Running(JoinHandle<T>)
The thread is running.
Completed
The thread completed or failed, the value was returned already. We have nothing to do.
Polling
Internal state where the poll state machine is being computed.